import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import java.util.*;

public class GraphicsDemo2 extends JFrame {
    int x;
    int y;
    final static int radius = 10;

    // Chaser objects are little red squares that
    // chase the user's oval around the window.
    class Chaser extends Thread {
        int myX;
        int myY;
        static final int myRadius = 3;

        Chaser() {
            reset();
        }

        public void run() {
            while (true) {
               if (move())
                   reset();

               repaint();

               try {
                   sleep(25);
               } catch (InterruptedException e) {
                   return;  
               }
            }  

        }

        // Move to a new position & detect a hit
        synchronized boolean move() {
            if (myX > x) myX--; else myX++;
            if (myY > y) myY--; else myY++;
            System.out.println(toString()+" moving to "+Integer.toString(myX)+
                               ","+Integer.toString(myY));
            return (Math.abs(myX-x)<radius && Math.abs(myY-y)<radius);
        }

        // Reset to a random position.
        synchronized void reset() {
            myX = (int)(Math.random()*200);
            myY = (int)(Math.random()*200);
        }

        // Draw the chaser object.
        synchronized public void draw(Graphics g) {
            g.setColor(Color.red);
            g.fillRect(myX-myRadius,myY-myRadius,myRadius*2,myRadius*2);
        }
    }

    Chaser chasers[] = new Chaser[5];

    public GraphicsDemo2(String title) {
        super(title);
        setup();
        setSize(200,200);
        getContentPane().setBackground(Color.black);
        addMouseListener(new MouseAdapter() {
            public void mousePressed(MouseEvent e) {
                x = e.getX();
                y = e.getY();
                repaint();     
            }
        });

        for(int i=0;i<chasers.length;++i) {
            chasers[i] = new Chaser();
            chasers[i].start();
        }     
    }

    public void paint(Graphics g) {
        super.paint(g);
        g.setColor(Color.green);
        g.fillOval(x-radius,y-radius,radius*2,radius*2);
        for(int i=0;i<chasers.length;++i) {
            chasers[i].draw(g);
        }     
    }

    public void setup() {
        WindowListener l = new WindowAdapter() {
            public void windowClosing(WindowEvent e) {System.exit(0);}
        };
        addWindowListener(l);
    }

    public static void main(String[] args) {
         GraphicsDemo2 demo = new GraphicsDemo2("Graphics Demo");
         demo.setVisible(true);        
    }
}
