import javax.swing.*;
import java.awt.event.*;

// Just like GuiAlpha, but adds a handler
// that detects "window events"
// The handler calls System.exit() when
// the user closes the window, forcing
// the program to exit. 

public class GuiBeta {

    public static void main(String[] args) {
        // Create a free-floating window:
        JFrame jframe = new JFrame("GuiBeta");
        
        // Specify the size in pixels:
        jframe.setSize(400,100);
        
        // Show the window:
        jframe.setVisible(true);

        // Add a listener object to handle window events:
        WindowListener wl = new GuiBetaCloseHandler();
        jframe.addWindowListener(wl);
    }
}

// Create a listener class for use by GuiBeta:
class GuiBetaCloseHandler implements WindowListener {
    public void windowClosing(WindowEvent e) {
        System.out.println("Closing!");
        System.exit(0);
    }
    public void windowActivated(WindowEvent e) { 
        System.out.println("Activated!"); 
    }
    public void windowDeactivated(WindowEvent e) {
        System.out.println("Deactivated!"); 
    }
    public void windowClosed(WindowEvent e) { }
    public void windowOpened(WindowEvent e) { }
    public void windowIconified(WindowEvent e) { }
    public void windowDeiconified(WindowEvent e) { }
}

// Listeners are a kind of specialized Observer.
// There are several kinds of GUI Listener 
// interfaces, each specialized to receive
// particular kinds of events.
// 
// MouseMotionListener -- Mouse movements
// MouseListener --  Mouse clicks
// KeyListener -- Key down or key up
// ItemListener -- Selecting an item within a control 
// TextListener -- Detects newlines in text controls
// AdjustmentListener -- Scrollbar movement
// ActionListener -- Generic actions (including buttons & menus)
// WindowListener -- Top-level floating window events
// FocusListener -- Keyboard focus changes
// ComponentListener -- Change to component location or visibility
// ContainerListenr -- Adding or removing component from container

// Events are messages sent to Listeners which provide 
// additional information about what just happened.
// Most Listener interfaces have a specialized Event;
// for example, WindowListener accepts WindowEvents.

// Note that you can add multiple Listeners to a given
// component.  They all get notified when an event 
// occurs.

// The Listener architecture is very flexible.