import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import java.util.*;

// Similar to TextDemo, but uses a more
// sophisticated layout and adds a box
// to display past aliases.

// Demonstrates BoxLayout layout manager.

public class LayoutDemo extends JFrame {
    final JButton okButton;
    final JTextField userNameField;
    final JTextField pastAliasesField;

    String currentName=null;
    Vector pastAliases = new Vector();

    public void changeName(String userName) {
       if (currentName != null) 
           pastAliases.addElement(currentName);
       currentName = userName;
       System.out.println("Name changed to "+currentName); 
       pastAliasesField.setText(getAliases());
    }

    public String getAliases() {
        return pastAliases.toString();
    }

    public LayoutDemo(String title) {
        super(title);

        setup();

        // NEW:
        Container cp = getContentPane();
        cp.setLayout(new BoxLayout(cp, BoxLayout.Y_AXIS));

        // Layout structure:
        // +------------------------------------+
        // |+----------------------------------+|
        // || namePanel  (FlowLayout)          ||
        // |+----------------------------------+|
        // |+----------------------------------+|
        // || aliasPanel (FlowLayout)          ||
        // |+----------------------------------+|
        // |+----------------------------------+|
        // || buttonPanel (BoxLayout)          ||
        // |+----------------------------------+|
        // 

        // namePanel
        {
            JPanel namePanel = new JPanel();
            namePanel.setLayout(new FlowLayout() );

            userNameField = new JTextField(30);

            namePanel.add(new JLabel("Name:"));
            namePanel.add(userNameField);

            cp.add(namePanel);
        }

        // aliasPanel
        {
            JPanel aliasPanel = new JPanel();
            aliasPanel.setLayout(new FlowLayout());

            pastAliasesField = new JTextField(30);
            pastAliasesField.setEditable(false);

            aliasPanel.add(new JLabel("AKA: "));
            aliasPanel.add(pastAliasesField);

            cp.add(aliasPanel);
        }

        // buttonPanel
        {
            JPanel buttonPanel = new JPanel();
            buttonPanel.setLayout(new BoxLayout(buttonPanel,BoxLayout.X_AXIS));
            buttonPanel.setBorder(
                    BorderFactory.createEmptyBorder(0, 10, 10, 10));
            
            okButton = new JButton("OK");
            buttonPanel.add(okButton);

            // Put a bit of space between buttons:
            buttonPanel.add(Box.createRigidArea(new Dimension(15,0)));

            // Create a nonfunctional Cancel button just for fun:
            buttonPanel.add(new JButton("Cancel"));

            cp.add(buttonPanel);
        }

        ActionListener enteredHandler = new ActionListener() {
              int pushes = 0;
              public void actionPerformed(ActionEvent e) {  
                   changeName(userNameField.getText());
              }
        };

        // Change the name when the user pushes the
        // Enter key in the text field, or when the
        // user clicks the OK button.
        userNameField.addActionListener(enteredHandler);
        okButton.addActionListener(enteredHandler);

        pack( );
    }

    public void setup() {
        WindowListener l = new WindowAdapter() {
            public void windowClosing(WindowEvent e) {System.exit(0);}
        };
        addWindowListener(l);
    }

    public static void main(String[] args) {
         LayoutDemo demo = new LayoutDemo("Layout Demo");
         demo.setVisible(true);        
    }
}

// See the following for a tutorial on layout managers:
//  http://java.sun.com/docs/books/tutorial/uiswing/layout/using.html
