import javax.swing.*;
import java.awt.event.*;
import java.awt.*;

// A voting machine simulator.
// Demonstrates use of AWT/Swing GUI components:
// JFrame, layouts, JLabel, JButton.
//
// Note that VotingMachine is a subclass of JFrame.
// It is responsible for creating all of its 
// sub-objects (buttons & label) and laying them
// out properly. 

public class VotingMachine extends JFrame {
    public VotingMachine(String title, boolean pictures) {
        // Invoke the superclass (JFrame) constructor code:
        super(title);

        setupGUI(pictures);
    }

    void setupGUI(boolean pictures) {
        // Specify the size in pixels:
        setSize(400,300);
        
        // Make the frame's subobjects use flow layout.
        // (Strategy Pattern)
        Container cp = getContentPane();
        cp.setLayout(new BoxLayout(cp, BoxLayout.Y_AXIS));

        // Create the results panel:
        {
            JPanel countPanel = new JPanel();
            countPanel.setLayout(new FlowLayout() );
            // Create the count label:
            countLabel = new JLabel("");
            updateUI(); // Create initial text
            countPanel.add(new JLabel("Results:"));
            countPanel.add(countLabel);
            cp.add(countPanel);
        }

        // Create the Bush button:
        ImageIcon bushImage=null;
        if (pictures) 
            bushImage = new ImageIcon("bush.jpg");
        JButton bushButton = new JButton("Bush", bushImage);
        bushButton.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent e) {
                // Can access methods of outer object:
                voteForBush();
            }
        });

        // Create the Gore button:
        ImageIcon goreImage=null;
        if (pictures)
            goreImage = new ImageIcon("gore.jpg");
        JButton goreButton = new JButton("Gore", goreImage);
        goreButton.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent e) {
                voteForGore();
            }
        });

        // Create the lower button panel:
        {
            JPanel buttonPanel = new JPanel();
            buttonPanel.setLayout(new GridLayout(1,2) );
            buttonPanel.add(bushButton);
            buttonPanel.add(goreButton);
            cp.add(buttonPanel);
        }


        addWindowListener(new WindowAdapter() {
                public void windowClosing(WindowEvent e) {
                    System.exit(0);
                }
            }
        );

        // Resize frame to just fit contents:
        pack();
    }

    void updateUI() {
        countLabel.setText("Bush "+
                           Integer.toString(bushCount)+
                           ", Gore "+
                           Integer.toString(goreCount));
    }

    void voteForBush() {
        bushCount++;
        updateUI();
    }

    void voteForGore() {
        goreCount++;
        updateUI();
    }

    private int bushCount;
    private int goreCount;
    private JLabel countLabel;

    public static void main(String[] args) {
        // Create a free-floating window:
        VotingMachine vm = new VotingMachine("VotingMachine", true);
        
        // Show the window:
        vm.setVisible(true);
    }

}

